@@ -1,11 +1,11 @@
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 from craftr.core.actions import Action
 from craftr.core.configurable import Closure, Configurable
 from craftr.core.context import Context
-from craftr.core.plugin import IPlugin, IPluginLoader
+from craftr.core.plugin import IPlugin, IPluginLoader, Namespace, TaskFactory
 from craftr.core.project import Project
 from craftr.core.property import HavingProperties, Property
 from craftr.core.task import Task
